==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/BarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VerticalAnchoredCategorySeriesDescriptionMetadata } from "./VerticalAnchoredCategorySeriesDescriptionMetadata";
import { BarSeriesDescription } from "./BarSeriesDescription";
/**
 * @hidden
 */
export let BarSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class BarSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (BarSeriesDescriptionMetadata.a == null) {
                BarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BarSeriesDescriptionMetadata.c(BarSeriesDescriptionMetadata.a);
            }
            if (a.k(BarSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(BarSeriesDescriptionMetadata.a);
        }
        static c(a) {
            VerticalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            BarSeriesDescriptionMetadata.b(a);
            a.ad("BarSeries", () => new BarSeriesDescription());
            a.ac("BarSeries", BarSeriesDescriptionMetadata.a);
        }
    }
    BarSeriesDescriptionMetadata.$t = markType(BarSeriesDescriptionMetadata, 'BarSeriesDescriptionMetadata');
    BarSeriesDescriptionMetadata.a = null;
    return BarSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/BarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { VerticalAnchoredCategorySeriesDescriptionMetadata } from "./VerticalAnchoredCategorySeriesDescriptionMetadata";
import { BarSeriesDescription } from "./BarSeriesDescription";
/**
 * @hidden
 */
export let BarSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class BarSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (BarSeriesDescriptionMetadata.a == null) {
                BarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                BarSeriesDescriptionMetadata.c(BarSeriesDescriptionMetadata.a);
            }
            if (a.k(BarSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(BarSeriesDescriptionMetadata.a);
        }
        static c(a) {
            VerticalAnchoredCategorySeriesDescriptionMetadata.c(a);
            a.item("RadiusX", "Number:double");
            a.item("RadiusY", "Number:double");
        }
        static d(a) {
            BarSeriesDescriptionMetadata.b(a);
            a.ae("BarSeries", () => new BarSeriesDescription());
            a.ad("BarSeries", BarSeriesDescriptionMetadata.a);
        }
    }
    BarSeriesDescriptionMetadata.$t = markType(BarSeriesDescriptionMetadata, 'BarSeriesDescriptionMetadata');
    BarSeriesDescriptionMetadata.a = null;
    return BarSeriesDescriptionMetadata;
})();
